@@ -1,50 +1,46 @@
-#' HERE Routing API: Route Matrix
+#' HERE Routing API: Calculate Matrix
 #'
-#' Calculates a matrix of route summaries between given points of interest (POIs).
+#' Calculates a matrix of route summaries between given points of interest (POIs) using the HERE 'Routing' API.
 #' Various transport modes and traffic information at a provided timestamp are supported.
 #' The requested matrix is split into (sub-)matrices of dimension 15x100 to use the
 #' maximum matrix size per request and thereby minimize the number of overall needed requests.
-#' The result is one route summary matrix, that fits the order of the provided POIs: \code{startIndex}, \code{destinationIndex}.
+#' The result is one route summary matrix, that fits the order of the provided POIs: \code{origIndex}, \code{destIndex}.
 #'
 #' @references
 #' \href{https://developer.here.com/documentation/routing/topics/resource-calculate-matrix.html}{HERE Routing API: Calculate Matrix}
 #'
-#' @param start \code{sf} object, Points of Interest (POIs) of geometry type \code{POINT} for the start locations.
-#' @param destination \code{sf} object, Points of Interest (POIs) of geometry type \code{POINT} for the destination locations.
+#' @param origin \code{sf} object, the origin locations of geometry type \code{POINT}.
+#' @param destination \code{sf} object, the destination locations of geometry type \code{POINT}.
+#' @param datetime \code{POSIXct} object, datetime for the departure.
 #' @param type character, set the routing type: \code{"fastest"}, \code{"shortest"} or \code{"balanced"}.
 #' @param mode character, set the transport mode: \code{"car"}, \code{"pedestrian"}, \code{"carHOV"} or \code{"truck"}.
-#' @param traffic boolean, use real-time traffic or prediction in routing (\code{default = FALSE})? If no \code{departure} date and time is set, the current timestamp at the moment of the request is used for \code{departure}.
-#' @param searchRange numeric, value in meters to limit the search radius in the route generation (\code{default = 99999999}).
+#' @param traffic boolean, use real-time traffic or prediction in routing (\code{default = FALSE})? If no \code{datetime} is set, the current timestamp at the moment of the request is used for \code{datetime}.
+#' @param search_range numeric, value in meters to limit the search radius in the route generation (\code{default = 99999999}).
 #' @param attribute character, attributes to be calculated on the routes: \code{"distance"} or \code{"traveltime"} (\code{default = c("distance", "traveltime")}.
-#' @param departure datetime, timestamp of type \code{POSIXct}, \code{POSIXt} for the departure.
 #' @param url_only boolean, only return the generated URLs (\code{default = FALSE})?
 #'
 #' @return
-#' A \code{data.table} containing the requested route matrix data.
+#' A \code{data.frame} containing the requested route matrix data.
 #' @export
 #'
 #' @examples
-#' # Authentication
-#' set_auth(
-#'   app_id = "<YOUR APP ID>",
-#'   app_code = "<YOUR APP CODE>"
-#' )
+#' # Provide an API Key for a HERE project
+#' set_key("<YOUR API KEY>")
 #'
 #' # Create routes summaries between all POIs
 #' mat <- route_matrix(
-#'   start = poi,
-#'   departure = as.POSIXct("2019-10-10 15:45:00"),
+#'   origin = poi,
 #'   traffic = TRUE,
 #'   url_only = TRUE
 #' )
-route_matrix <- function(start, destination = start, type = "fastest", mode = "car",
-                         traffic = FALSE, searchRange = 99999999,
-                         attribute = c("distance", "traveltime"),
-                         departure = NULL, url_only = FALSE) {
+route_matrix <- function(origin, destination = origin, datetime = Sys.time(),
+                         type = "fastest", mode = "car", traffic = FALSE,
+                         search_range = 99999999, attribute = c("distance", "traveltime"),
+                         url_only = FALSE) {
   # Checks
-  .check_points(start)
+  .check_points(origin)
   .check_points(destination)
-  .check_datetime(departure)
+  .check_datetime(datetime)
   .check_attributes(attribute)
   .check_type(type = type, request = "calculatematrix")
   .check_mode(mode = mode, request = "calculatematrix")
@@ -52,11 +48,11 @@ route_matrix <- function(start, destination = start, type = "fastest", mode = "c
   .check_boolean(url_only)
 
   # CRS transformation and formatting
-  start <- sf::st_coordinates(
-    sf::st_transform(start, 4326)
+  origin <- sf::st_coordinates(
+    sf::st_transform(origin, 4326)
   )
-  start <- paste0(
-    "geo!", start[, 2], ",", start[, 1]
+  origin <- paste0(
+    "geo!", origin[, 2], ",", origin[, 1]
   )
   destination <- sf::st_coordinates(
     sf::st_transform(destination, 4326)
@@ -65,41 +61,41 @@ route_matrix <- function(start, destination = start, type = "fastest", mode = "c
     "geo!", destination[, 2], ",", destination[, 1]
   )
 
-  # Add authentication
-  url <- .add_auth(
-    url = "https://matrix.route.api.here.com/routing/7.2/calculatematrix.json?"
+  # Add API key
+  url <- .add_key(
+    url = "https://matrix.route.ls.hereapi.com/routing/7.2/calculatematrix.json?"
   )
 
   # Switch coordinates to use max request size of 15x100
-  if (length(start) > length(destination)) {
+  if (length(origin) > length(destination)) {
     switch <- TRUE
-    start_tmp <- start
-    start <- destination
-    destination <- start_tmp
+    origin_tmp <- origin
+    origin <- destination
+    destination <- origin_tmp
   } else {
     switch <- FALSE
   }
 
   # Create batches, indices and format coordinates
-  batch_size_start <- 15
+  batch_size_origin <- 15
   batch_size_dest <- 100
-  start_div <- seq(0, length(start), batch_size_start)
+  orig_div <- seq(0, length(origin), batch_size_origin)
   dest_div <- seq(0, length(destination), batch_size_dest)
-  start_idx <- list()
+  orig_idx <- list()
   dest_idx <- list()
 
-  coords <- sapply(X = start_div, FUN = function(i) {
-    start_batch <- start[(i + 1):(i + batch_size_start)]
-    start_batch <- start_batch[!is.na(start_batch)]
+  coords <- sapply(X = orig_div, FUN = function(i) {
+    origin_batch <- origin[(i + 1):(i + batch_size_origin)]
+    origin_batch <- origin_batch[!is.na(origin_batch)]
     for (j in dest_div) {
       dest_batch <- destination[(j + 1):(j + batch_size_dest)]
       dest_batch <- dest_batch[!is.na(dest_batch)]
-      start_idx <<- append(start_idx, list(seq(0 + i, length(start_batch) - 1 + i, 1)))
+      orig_idx <<- append(orig_idx, list(seq(0 + i, length(origin_batch) - 1 + i, 1)))
       dest_idx <<- append(dest_idx, list(seq(0 + j, length(dest_batch) - 1 + j, 1)))
       return(paste0("&",
              paste0("start",
-                    seq(0, length(start_batch) - 1, 1), "=",
-                    start_batch,
+                    seq(0, length(origin_batch) - 1, 1), "=",
+                    origin_batch,
                     collapse = "&"), "&",
              paste0("destination",
                     seq(0, length(dest_batch) - 1, 1), "=",
@@ -109,7 +105,7 @@ route_matrix <- function(start, destination = start, type = "fastest", mode = "c
     }
   })
 
-  # Add start coords
+  # Add origin coords
   url = paste0(
     url,
     coords
@@ -123,17 +119,17 @@ route_matrix <- function(start, destination = start, type = "fastest", mode = "c
     traffic = traffic
   )
 
-  # Add searchRange
+  # Add search range
   url = paste0(
     url,
     "&searchRange=",
-    searchRange
+    search_range
   )
 
   # Add departure time
   url <- .add_datetime(
     url,
-    departure,
+    datetime,
     "departure"
   )
 
@@ -159,24 +155,30 @@ route_matrix <- function(start, destination = start, type = "fastest", mode = "c
     lapply(data, function(con) {
       df <- jsonlite::fromJSON(con)$response$matrixEntry
       # Retrieve original indices
-      df$startIndex <- start_idx[[count]][df$startIndex + 1] + 1
-      df$destinationIndex <- dest_idx[[count]][df$destinationIndex + 1] + 1
+      df$origIndex <- orig_idx[[count]][df$startIndex + 1] + 1
+      df$destIndex <- dest_idx[[count]][df$destinationIndex + 1] + 1
       count <<- count + 1
       # Flatten columns
-      cbind(df[, 1:2], df$summary)
+      cbind(df[, c("origIndex", "destIndex")], df$summary)
     })
   )
 
   # Switch back indices
   if (switch) {
-    tmp <- routes$startIndex
-    routes$startIndex <- routes$destinationIndex
-    routes$destinationIndex <- tmp
+    tmp <- routes$origIndex
+    routes$origIndex <- routes$destIndex
+    routes$destIndex <- tmp
   }
 
+  # Add departure and arrival
+  routes$departure <- datetime
+  routes$arrival <- datetime + routes$travelTime
+  routes <- routes[, c("origIndex", "destIndex", "departure", "arrival",
+                       "distance", "travelTime", "costFactor")]
+
   # Reorder
-  routes <- routes[order(routes$startIndex,
-                         routes$destinationIndex), ]
+  routes <- routes[order(routes$origIndex,
+                         routes$destIndex), ]
   rownames(routes) <- NULL
-  return(routes)
+  return(as.data.frame(routes))
 }
