@@ -1,6 +1,6 @@
 #' HERE Traffic API: Flow and Incidents
 #'
-#' Real-time traffic flow and incident information based on the 'Traffic' API.
+#' Real-time traffic flow and incident information based on the HERE 'Traffic' API in areas of interest (AOIs).
 #' The traffic flow data contains speed (\code{"SP"}) and congestion (jam factor: \code{"JF"}) information.
 #' Traffic incidents contain information about location, time, duration, severity, description and other details.
 #'
@@ -12,9 +12,9 @@
 #'
 #' @param aoi \code{sf} object, Areas of Interest (POIs) of geometry type \code{POLYGON}.
 #' @param product character, traffic product of the 'Traffic API'. Supported products: \code{"flow"} and \code{"incidents"}.
-#' @param from_dt datetime, timestamp of type \code{POSIXct}, \code{POSIXt} for the earliest traffic incidents (Note: Only takes effect if \code{product} is set to \code{"incidents"}).
-#' @param to_dt datetime, timestamp of type \code{POSIXct}, \code{POSIXt} for the latest traffic incidents (Note: Only takes effect if \code{product} is set to \code{"incidents"}).
-#' @param local_time boolean, should time values in the response for traffic incidents be in the local time of the incident or in UTC (\code{default = FALSE})?
+#' @param from \code{POSIXct} object, datetime of the earliest traffic incidents (Note: Only takes effect if \code{product} is set to \code{"incidents"}).
+#' @param to \code{POSIXct} object, datetime of the latest traffic incidents (Note: Only takes effect if \code{product} is set to \code{"incidents"}).
+#' @param min_jam_factor numeric, only retrieve flow information with a jam factor greater than the value provided (Note: Only takes effect if \code{product} is set to \code{"flow"}, \code{default = 0}).
 #' @param url_only boolean, only return the generated URLs (\code{default = FALSE})?
 #'
 #' @return
@@ -36,11 +36,8 @@
 #' }
 #'
 #' @examples
-#' # Authentication
-#' set_auth(
-#'   app_id = "<YOUR APP ID>",
-#'   app_code = "<YOUR APP CODE>"
-#' )
+#' # Provide an API Key for a HERE project
+#' set_key("<YOUR API KEY>")
 #'
 #' # Real-time traffic flow
 #' flow <- traffic(
@@ -53,30 +50,30 @@
 #' incidents <- traffic(
 #'   aoi = aoi[aoi$code == "LI", ],
 #'   product = "incidents",
-#'   from_dt = as.POSIXct("2018-01-01 00:00:00"),
-#'   to_dt = as.POSIXct("2019-12-31 23:59:59"),
+#'   from = as.POSIXct("2018-01-01 00:00:00"),
+#'   to = as.POSIXct("2019-12-31 23:59:59"),
 #'   url_only = TRUE
 #' )
-traffic <- function(aoi, product = "flow", from_dt = NULL, to_dt = NULL,
-                    local_time = FALSE, url_only = FALSE) {
+traffic <- function(aoi, product = "flow", from = NULL, to = NULL,
+                    min_jam_factor = 0, url_only = FALSE) {
 
   # Checks
   .check_polygon(aoi)
-  .check_datetime(from_dt)
-  .check_datetime(to_dt)
-  if (!(is.null(from_dt) | is.null(to_dt)))
-    .check_datetime_range(from_dt, to_dt)
+  .check_datetime(from)
+  .check_datetime(to)
+  if (!(is.null(from) | is.null(to)))
+    .check_datetime_range(from, to)
   .check_traffic_product(product)
-  if ((!is.null(from_dt) | !is.null(to_dt)) & product == "flow") {
-    from_dt <- to_dt <- NULL
-    message("Note: 'from_dt' and 'to_dt' have no effect on traffic flow. Traffic flow is always real-time.")
+  if ((!is.null(from) | !is.null(to)) & product == "flow") {
+    from <- to <- NULL
+    message("Note: 'from' and 'to' have no effect on traffic flow. Traffic flow is always real-time.")
   }
-  .check_boolean(local_time)
+  .check_min_jam_factor(min_jam_factor)
   .check_boolean(url_only)
 
-  # Add authentication
-  url <- .add_auth(
-    url = sprintf("https://traffic.api.here.com/traffic/6.2/%s.json?",
+  # Add API key
+  url <- .add_key(
+    url = sprintf("https://traffic.ls.hereapi.com/traffic/6.2/%s.json?",
                   product)
   )
 
@@ -99,22 +96,30 @@ traffic <- function(aoi, product = "flow", from_dt = NULL, to_dt = NULL,
   # Add datetime range
   url <- .add_datetime(
     url = url,
-    datetime = from_dt,
+    datetime = from,
     field_name = "startTime"
   )
   url <- .add_datetime(
     url = url,
-    datetime = to_dt,
+    datetime = to,
     field_name = "endTime"
   )
 
   # Add time zone
   url <- paste0(
     url,
-    "&localtime=",
-    local_time
+    "&localtime=false"
   )
 
+  # Add min jam factor
+  if (product == "flow") {
+    url <- paste0(
+      url,
+      "&minjamfactor=",
+      min_jam_factor
+    )
+  }
+
   # Return urls if chosen
   if (url_only) return(url)
 
@@ -126,7 +131,7 @@ traffic <- function(aoi, product = "flow", from_dt = NULL, to_dt = NULL,
 
   # Extract information
   if (product == "flow") {
-    traffic <- .extract_traffic_flow(data)
+    traffic <- .extract_traffic_flow(data, min_jam_factor)
   } else if (product == "incidents") {
     traffic <- .extract_traffic_incidents(data)
   }
@@ -141,7 +146,7 @@ traffic <- function(aoi, product = "flow", from_dt = NULL, to_dt = NULL,
   return(traffic)
 }
 
-.extract_traffic_flow <- function(data) {
+.extract_traffic_flow <- function(data, min_jam_factor) {
   ids <- .get_ids(data)
   count <- 0
   geoms <- list()
@@ -175,10 +180,12 @@ traffic <- function(aoi, product = "flow", from_dt = NULL, to_dt = NULL,
       }), fill = TRUE)
     }), fill = TRUE))
   flow$geometry <- geoms
+  flow <- flow[flow$JF >= min_jam_factor, ]
   if (nrow(flow) > 0) {
     return(
       sf::st_set_crs(
-        sf::st_as_sf(flow), 4326
+        sf::st_as_sf(
+          as.data.frame(flow)), 4326
       )
     )
   } else {
@@ -196,16 +203,16 @@ traffic <- function(aoi, product = "flow", from_dt = NULL, to_dt = NULL,
     if (is.null(df$TRAFFIC_ITEMS)) {return(NULL)}
     info <- data.table::data.table(
       id = ids[count],
-      incident_id = df$TRAFFIC_ITEMS$TRAFFIC_ITEM$TRAFFIC_ITEM_ID,
-      entry_dt = as.POSIXct(df$TRAFFIC_ITEMS$TRAFFIC_ITEM$ENTRY_TIME, format="%m/%d/%Y %H:%M:%S"),
-      from_dt = as.POSIXct(df$TRAFFIC_ITEMS$TRAFFIC_ITEM$START_TIME, format="%m/%d/%Y %H:%M:%S"),
-      to_dt = as.POSIXct(df$TRAFFIC_ITEMS$TRAFFIC_ITEM$END_TIME, format="%m/%d/%Y %H:%M:%S"),
+      incidentId = df$TRAFFIC_ITEMS$TRAFFIC_ITEM$TRAFFIC_ITEM_ID,
+      entryTime = .parse_datetime(df$TRAFFIC_ITEMS$TRAFFIC_ITEM$ENTRY_TIME, format = "%m/%d/%Y %H:%M:%OS"),
+      fromTime = .parse_datetime(df$TRAFFIC_ITEMS$TRAFFIC_ITEM$START_TIME, format = "%m/%d/%Y %H:%M:%OS"),
+      toTime = .parse_datetime(df$TRAFFIC_ITEMS$TRAFFIC_ITEM$END_TIME, format = "%m/%d/%Y %H:%M:%OS"),
       status = tolower(df$TRAFFIC_ITEMS$TRAFFIC_ITEM$TRAFFIC_ITEM_STATUS_SHORT_DESC),
       type = tolower(df$TRAFFIC_ITEMS$TRAFFIC_ITEM$TRAFFIC_ITEM_TYPE_DESC),
       verified = df$TRAFFIC_ITEMS$TRAFFIC_ITEM$VERIFIED,
       criticality = as.numeric(df$TRAFFIC_ITEMS$TRAFFIC_ITEM$CRITICALITY$ID),
-      road_closed = df$TRAFFIC_ITEMS$TRAFFIC_ITEM$TRAFFIC_ITEM_DETAIL$ROAD_CLOSED,
-      location_name = df$TRAFFIC_ITEMS$TRAFFIC_ITEM$LOCATION$POLITICAL_BOUNDARY$COUNTY,
+      roadClosed = df$TRAFFIC_ITEMS$TRAFFIC_ITEM$TRAFFIC_ITEM_DETAIL$ROAD_CLOSED,
+      locationName = df$TRAFFIC_ITEMS$TRAFFIC_ITEM$LOCATION$POLITICAL_BOUNDARY$COUNTY,
       lng = df$TRAFFIC_ITEMS$TRAFFIC_ITEM$LOCATION$GEOLOC$ORIGIN$LONGITUDE,
       lat = df$TRAFFIC_ITEMS$TRAFFIC_ITEM$LOCATION$GEOLOC$ORIGIN$LATITUDE,
       description = sapply(df$TRAFFIC_ITEMS$TRAFFIC_ITEM$TRAFFIC_ITEM_DESCRIPTION, function(x) x$value[2])
@@ -225,7 +232,9 @@ traffic <- function(aoi, product = "flow", from_dt = NULL, to_dt = NULL,
   if (nrow(incidents) > 0) {
     return(
       sf::st_set_crs(
-        sf::st_as_sf(incidents, coords = c("lng", "lat")), 4326
+        sf::st_as_sf(
+          as.data.frame(incidents),
+          coords = c("lng", "lat")), 4326
       )
     )
   } else {
